@@ -1,4 +1,4 @@
-""" Import Qt in a manner suitable for an IPython kernel.
+"""Import Qt in a manner suitable for an IPython kernel.
 
 This is the import used for the `gui=qt` or `matplotlib=qt` initialization.
 
@@ -23,6 +23,9 @@ if QT_API not set:
 else:
     use what QT_API says
 
+    Note that %gui's implementation will always set a `QT_API`, see
+    `IPython.terminal.pt_inputhooks.get_inputhook_name_and_func`
+
 """
 # NOTE: This is no longer an external, third-party module, and should be
 # considered part of IPython. For compatibility however, it is being kept in
@@ -31,7 +34,6 @@ else:
 import os
 import sys
 
-from IPython.utils.version import check_version
 from IPython.external.qt_loaders import (
     load_qt,
     loaded_api,
@@ -43,7 +45,6 @@ from IPython.external.qt_loaders import (
     QT_API_PYQT5,
     QT_API_PYSIDE2,
     # QT4
-    QT_API_PYQTv1,
     QT_API_PYQT,
     QT_API_PYSIDE,
     # default
@@ -57,10 +58,6 @@ _qt_apis = (
     # QT5
     QT_API_PYQT5,
     QT_API_PYSIDE2,
-    # QT4
-    QT_API_PYQTv1,
-    QT_API_PYQT,
-    QT_API_PYSIDE,
     # default
     QT_API_PYQT_DEFAULT,
 )
@@ -99,10 +96,10 @@ def get_options():
     if loaded is not None:
         return [loaded]
 
-    mpl = sys.modules.get('matplotlib', None)
+    mpl = sys.modules.get("matplotlib", None)
 
-    if mpl is not None and not check_version(mpl.__version__, '1.0.2'):
-        #1.0.1 only supports PyQt4 v1
+    if mpl is not None and tuple(mpl.__version__.split(".")) < ("1", "0", "2"):
+        # 1.0.1 only supports PyQt4 v1
         return [QT_API_PYQT_DEFAULT]
 
     qt_api = os.environ.get('QT_API', None)
@@ -114,8 +111,6 @@ def get_options():
             QT_API_PYSIDE6,
             QT_API_PYQT5,
             QT_API_PYSIDE2,
-            QT_API_PYQT,
-            QT_API_PYSIDE,
         ]
     elif qt_api not in _qt_apis:
         raise RuntimeError("Invalid Qt API %r, valid values are: %r" %
