@@ -7,8 +7,9 @@ import builtins
 import os
 import sys
 import platform
+from pathlib import Path
 
-from tempfile import NamedTemporaryFile
+from tempfile import NamedTemporaryFile, TemporaryDirectory
 from textwrap import dedent
 from unittest.mock import patch
 
@@ -625,3 +626,314 @@ def test_where_erase_value():
     child.expect("ipdb>")
 
     child.close()
+
+
+@skip_win32
+def test_ignore_module_basic_functionality():
+    """Test basic ignore/unignore functionality and error handling."""
+    import pexpect
+
+    env = os.environ.copy()
+    env["IPY_TEST_SIMPLE_PROMPT"] = "1"
+
+    with TemporaryDirectory() as temp_dir:
+        main_path = create_test_modules(temp_dir)
+
+        child = pexpect.spawn(sys.executable, [main_path], env=env, cwd=temp_dir)
+        child.timeout = 15 * IPYTHON_TESTING_TIMEOUT_SCALE
+        child.expect("ipdb>")
+
+        # Test listing modules when none are ignored
+        child.sendline("ignore_module")
+        child.expect_exact("No modules are currently ignored.")
+        child.expect("ipdb>")
+
+        # Test ignoring a module
+        child.sendline("ignore_module level2_module")
+        child.expect("ipdb>")
+
+        # Test listing ignored modules
+        child.sendline("ignore_module")
+        child.expect_exact("Currently ignored modules: ['level2_module']")
+        child.expect("ipdb>")
+
+        # Test wildcard pattern
+        child.sendline("ignore_module testpkg.*")
+        child.expect("ipdb>")
+
+        child.sendline("ignore_module")
+        child.expect_exact("Currently ignored modules: ['level2_module', 'testpkg.*']")
+        child.expect("ipdb>")
+
+        # Test error handling - removing non-existent module
+        child.sendline("unignore_module nonexistent")
+        child.expect_exact("Module nonexistent is not currently ignored")
+        child.expect("ipdb>")
+
+        # Test successful removal
+        child.sendline("unignore_module level2_module")
+        child.expect("ipdb>")
+
+        child.sendline("ignore_module")
+        child.expect_exact("Currently ignored modules: ['testpkg.*']")
+        child.expect("ipdb>")
+
+        # Test removing already removed module
+        child.sendline("unignore_module level2_module")
+        child.expect_exact("Module level2_module is not currently ignored")
+        child.expect("ipdb>")
+
+        # Remove wildcard pattern
+        child.sendline("unignore_module testpkg.*")
+        child.expect("ipdb>")
+
+        child.sendline("ignore_module")
+        child.expect_exact("No modules are currently ignored.")
+        child.expect("ipdb>")
+
+        child.sendline("continue")
+        child.close()
+
+
+# Helper function for creating temporary modules
+def create_test_modules(temp_dir):
+    """Create a comprehensive module hierarchy for testing all debugger commands."""
+
+    temp_path = Path(temp_dir)
+
+    # Create package structure for wildcard testing
+    package_dir = temp_path / "testpkg"
+    package_dir.mkdir()
+
+    # Package __init__.py
+    (package_dir / "__init__.py").write_text("# Test package")
+
+    # testpkg/submod1.py
+    (package_dir / "submod1.py").write_text(
+        dedent(
+            """
+        def submod1_func():
+            x = 1
+            y = 2
+            return x + y
+        """
+        )
+    )
+
+    # testpkg/submod2.py
+    (package_dir / "submod2.py").write_text(
+        dedent(
+            """
+        def submod2_func():
+            z = 10
+            return z * 2
+        """
+        )
+    )
+
+    # Level 1 (top level module)
+    (temp_path / "level1_module.py").write_text(
+        dedent(
+            """
+        from level2_module import level2_func
+
+        def level1_func():
+            return level2_func()
+        """
+        )
+    )
+
+    # Level 2 (middle level module)
+    (temp_path / "level2_module.py").write_text(
+        dedent(
+            """
+        from level3_module import level3_func
+        from testpkg.submod1 import submod1_func
+        from testpkg.submod2 import submod2_func
+
+        def level2_func():
+            # Call package functions for step/next testing
+            result1 = submod1_func()
+            result2 = submod2_func()
+            return level3_func() + result1 + result2
+        """
+        )
+    )
+
+    # Level 3 (bottom level with debugger)
+    (temp_path / "level3_module.py").write_text(
+        dedent(
+            """
+        from level4_module import level4_func
+
+        from IPython.core.debugger import set_trace
+
+        def level3_func():
+            set_trace()
+            pass
+            result = level4_func()
+            return result
+        """
+        )
+    )
+
+    # Level 4 (bottom level with debugger)
+    (temp_path / "level4_module.py").write_text(
+        dedent(
+            """
+        def level4_func():
+            a = 70
+            b = 30
+            return a + b
+        """
+        )
+    )
+
+    # Main runner
+    main_path = temp_path / "main_runner.py"
+    main_path.write_text(
+        dedent(
+            """
+        import sys
+        sys.path.insert(0, '.')
+        from level1_module import level1_func
+
+        if __name__ == "__main__":
+            result = level1_func()
+            print(f"Final result: {result}")
+        """
+        )
+    )
+
+    return str(main_path)
+
+
+@skip_win32
+def test_ignore_module_all_commands():
+    """Comprehensive test for all debugger commands (up/down/step/next) with ignore functionality."""
+    import pexpect
+
+    env = os.environ.copy()
+    env["IPY_TEST_SIMPLE_PROMPT"] = "1"
+
+    with TemporaryDirectory() as temp_dir:
+        main_path = create_test_modules(temp_dir)
+
+        # Test UP and DOWN commands
+        child = pexpect.spawn(sys.executable, [main_path], env=env, cwd=temp_dir)
+        child.timeout = 15 * IPYTHON_TESTING_TIMEOUT_SCALE
+        child.expect("ipdb>")
+
+        # Test up without ignores (baseline)
+        child.sendline("up")
+        child.expect("ipdb>")
+        child.sendline("__name__")
+        child.expect_exact("level2_module")
+        child.expect("ipdb>")
+
+        # Reset position
+        child.sendline("down")
+        child.expect("ipdb>")
+
+        # Test up with single module ignore
+        child.sendline("ignore_module level2_module")
+        child.expect("ipdb>")
+        child.sendline("up")
+        child.expect_exact(
+            "[... skipped 1 frame(s): 0 hidden frames + 1 ignored modules]"
+        )
+        child.expect("ipdb>")
+        child.sendline("__name__")
+        child.expect_exact("level1_module")
+        child.expect("ipdb>")
+
+        # Test up with wildcard ignore
+        child.sendline("down")
+        child.expect_exact(
+            "[... skipped 1 frame(s): 0 hidden frames + 1 ignored modules]"
+        )
+        child.expect("ipdb>")
+        child.sendline("unignore_module level2_module")
+        child.expect("ipdb>")
+        child.sendline("ignore_module level*")
+        child.expect("ipdb>")
+        child.sendline("up")
+        child.expect_exact(
+            "[... skipped 2 frame(s): 0 hidden frames + 2 ignored modules]"
+        )
+        child.expect("ipdb>")
+        child.sendline("__name__")
+        child.expect_exact("__main__")
+        child.expect("ipdb>")
+
+        child.sendline("continue")
+        child.close()
+
+        # Test STEP command
+        child = pexpect.spawn(sys.executable, [main_path], env=env, cwd=temp_dir)
+        child.timeout = 15 * IPYTHON_TESTING_TIMEOUT_SCALE
+        child.expect("ipdb>")
+
+        # Test step without ignores (should step into module)
+        child.sendline("until 9")
+        child.expect("ipdb>")
+        child.sendline("step")
+        child.expect("ipdb>")
+        child.sendline("__name__")
+        child.expect_exact("level4_module")
+        child.expect("ipdb>")
+
+        child.sendline("continue")
+        child.close()
+
+        # Test step with single module ignore
+        child = pexpect.spawn(sys.executable, [main_path], env=env, cwd=temp_dir)
+        child.timeout = 15 * IPYTHON_TESTING_TIMEOUT_SCALE
+        child.expect("ipdb>")
+
+        child.sendline("ignore_module level4_module")
+        child.expect("ipdb>")
+        child.sendline("until 9")
+        child.expect("ipdb>")
+        child.sendline("step")
+        child.expect_exact("[... skipped 1 ignored module(s)]")
+        child.expect("ipdb>")
+        child.sendline("__name__")
+        child.expect_exact("level3_module")
+        child.expect("ipdb>")
+
+        child.sendline("continue")
+        child.close()
+
+        # Test NEXT command
+        child = pexpect.spawn(sys.executable, [main_path], env=env, cwd=temp_dir)
+        child.timeout = 15 * IPYTHON_TESTING_TIMEOUT_SCALE
+        child.expect("ipdb>")
+
+        # Test next without ignores
+        child.sendline("until 9")
+        child.expect("ipdb>")
+        child.sendline("next")
+        child.expect("ipdb>")
+        child.sendline("__name__")
+        child.expect_exact("level3_module")
+        child.expect("ipdb>")
+
+        child.sendline("continue")
+        child.close()
+
+        # Test next with module ignore
+        child = pexpect.spawn(sys.executable, [main_path], env=env, cwd=temp_dir)
+        child.timeout = 15 * IPYTHON_TESTING_TIMEOUT_SCALE
+        child.expect("ipdb>")
+
+        child.sendline("ignore_module level2_module")
+        child.expect("ipdb>")
+        child.sendline("return")
+        child.expect("ipdb>")
+        child.sendline("next")
+        child.expect_exact("[... skipped 1 ignored module(s)]")
+        child.expect("ipdb>")
+
+        child.sendline("continue")
+        child.close()
